@@ -5,7 +5,7 @@ horizon.forms = {
       var $option = $(this).find("option:selected");
       var $form = $(this).closest('form');
       var $volName = $form.find('input#id_name');
-      if ($volName.val() == "") {
+      if ($volName.val() === "") {
         $volName.val($option.data("name"));
       }
       var $volSize = $form.find('input#id_size');
@@ -22,7 +22,7 @@ horizon.forms = {
       var $option = $(this).find("option:selected");
       var $form = $(this).closest('form');
       var $volName = $form.find('input#id_name');
-      if ($volName.val() == "") {
+      if ($volName.val() === "") {
         $volName.val($option.data("name"));
       }
       var $volSize = $form.find('input#id_size');
@@ -39,7 +39,7 @@ horizon.forms = {
       var $option = $(this).find("option:selected");
       var $form = $(this).closest('form');
       var $volName = $form.find('input#id_name');
-      if ($volName.val() == "") {
+      if ($volName.val() === "") {
         $volName.val($option.data("name"));
       }
       var $volSize = $form.find('input#id_size');
@@ -56,25 +56,63 @@ horizon.forms = {
     });
   },
 
+  /**
+   * In the container's upload object form, copy the selected file name in the
+   * object name field if the field is empty. The filename string is stored in
+   * the input as an attribute "filename". The value is used as comparison to
+   * compare with the value of the new filename string.
+   */
+  handle_object_upload_source: function() {
+    $("div.table_wrapper, #modal_wrapper").on("change", "input#id_object_file", function(evt) {
+      if (typeof($(this).attr("filename")) === 'undefined') {
+        $(this).attr("filename", "");
+      }
+      var $form = $(this).closest("form");
+      var $obj_name = $form.find("input#id_name");
+      var $fullPath = $(this).val();
+      var $startIndex = ($fullPath.indexOf('\\') >= 0 ? $fullPath.lastIndexOf('\\') : $fullPath.lastIndexOf('/'));
+      var $filename = $fullPath.substring($startIndex);
+
+      if ($filename.indexOf('\\') === 0 || $filename.indexOf('/') === 0) {
+        $filename = $filename.substring(1);
+      }
+
+      if (typeof($obj_name.val()) === 'undefined' || $(this).attr("filename").localeCompare($obj_name.val()) === 0) {
+        $obj_name.val($filename);
+        $(this).attr("filename", $filename);
+        $obj_name.trigger('input');
+      }
+    });
+  },
+
   datepicker: function() {
-    var startDate = $('input#id_start').datepicker()
+    var startDate = $('input#id_start').datepicker({ language: horizon.datepickerLocale })
       .on('changeDate', function(ev) {
-        if (ev.date.valueOf() > endDate.date.valueOf()) {
-          var newDate = new Date(ev.date);
+        if (ev.dates[0].valueOf() > endDate.dates[0].valueOf()) {
+          var newDate = new Date(ev.dates[0]);
           newDate.setDate(newDate.getDate() + 1);
-          endDate.setValue(newDate);
+          endDate.setDate(newDate);
           $('input#id_end')[0].focus();
         }
         startDate.hide();
+        endDate.setStartDate(ev.dates[0]);
+        endDate.update();
       }).data('datepicker');
 
     var endDate = $('input#id_end').datepicker({
-      onRender: function(date) {
-        return date.valueOf() < startDate.date.valueOf() ? 'disabled' : '';
-      }
+      language: horizon.datepickerLocale,
+      startDate: startDate ? startDate.dates[0] : null
     }).on('changeDate', function(ev) {
         endDate.hide();
       }).data('datepicker');
+
+    $("input#id_start").mousedown(function(){
+      endDate.hide();
+    });
+
+    $("input#id_end").mousedown(function(){
+      startDate.hide();
+    });
   }
 };
 
@@ -84,7 +122,7 @@ horizon.forms.bind_add_item_handlers = function (el) {
     var $this = $(this);
     $button = $("<a href='" + $this.attr("data-add-item-url") + "' " +
       "data-add-to-field='" + $this.attr("id") + "' " +
-      "class='btn ajax-add ajax-modal btn-inline'>+</a>");
+      "class='btn ajax-add ajax-modal btn-default'>+</a>");
     $this.after($button);
   });
 };
@@ -105,6 +143,46 @@ horizon.forms.prevent_multiple_submission = function (el) {
   });
 };
 
+horizon.forms.add_password_fields_reveal_buttons = function (el) {
+  var _change_input_type = function ($input, type) {
+    /*
+     * In a perfect world, this function would just do:
+     *
+     *   $input.attr('type', type);
+     *
+     * however, Microsoft Internet Explorer exists and we have to support it.
+     */
+
+    var $new_input = $input.clone();
+
+    $new_input.attr('type', type);
+    $input.replaceWith($new_input);
+    return $new_input;
+  };
+
+
+  $(el).find('input[type="password"]').each(function (i, input) {
+    var $input = $(input);
+
+    $input.closest('div').addClass("has-feedback");
+    $('<span>').addClass(
+      "form-control-feedback glyphicon glyphicon-eye-open"
+    ).insertAfter($input).click(function () {
+      var $icon = $(this);
+
+      if ($input.attr('type') === 'password') {
+        $icon.removeClass('glyphicon-eye-open');
+        $icon.addClass('glyphicon-eye-close');
+        $input = _change_input_type($input, 'text');
+      } else {
+        $icon.removeClass('glyphicon-eye-close');
+        $icon.addClass('glyphicon-eye-open');
+        $input = _change_input_type($input, 'password');
+      }
+    });
+  });
+};
+
 horizon.forms.init_examples = function (el) {
   var $el = $(el);
 
@@ -115,9 +193,6 @@ horizon.forms.init_examples = function (el) {
 
   // Table search box.
   $el.find(".table_search input").attr("placeholder", gettext("Filter"));
-
-  // Volume attachment form.
-  $el.find("#attach_volume_form #id_device").attr("placeholder", "/dev/vdc");
 };
 
 horizon.addInitFunction(function () {
@@ -133,8 +208,13 @@ horizon.addInitFunction(function () {
   horizon.forms.handle_snapshot_source();
   horizon.forms.handle_volume_source();
   horizon.forms.handle_image_source();
+  horizon.forms.handle_object_upload_source();
   horizon.forms.datepicker();
 
+  horizon.forms.add_password_fields_reveal_buttons($("body"));
+  horizon.modals.addModalInitFunction(
+    horizon.forms.add_password_fields_reveal_buttons);
+
   // Bind event handlers to confirm dangerous actions.
   $("body").on("click", "form button.btn-danger", function (evt) {
     horizon.datatables.confirm(this);
@@ -154,17 +234,20 @@ horizon.addInitFunction(function () {
         visible = $switchable.is(':visible'),
         val = $switchable.val();
 
-      $fieldset.find('.switched[data-switch-on*="' + slug + '"]').each(function(index, input){
+      function handle_switched_field(index, input){
         var $input = $(input),
           data = $input.data(slug + "-" + val);
 
         if (typeof data === "undefined" || !visible) {
-          $input.closest('.form-field').hide();
+          $input.closest('.form-group').hide();
         } else {
           $('label[for=' + $input.attr('id') + ']').html(data);
-          $input.closest('.form-field').show();
+          $input.closest('.form-group').show();
         }
-      });
+      }
+
+      $fieldset.find('.switched[data-switch-on*="' + slug + '"]').each(handle_switched_field);
+      $fieldset.siblings().find('.switched[data-switch-on*="' + slug + '"]').each(handle_switched_field);
     });
   });
 
@@ -182,9 +265,9 @@ horizon.addInitFunction(function () {
 
     $this.find("option").each(function () {
       if (this.value !== base_type) {
-        $("#id_" + this.value).closest(".control-group").hide();
+        $("#id_" + this.value).closest(".form-group").hide();
       } else {
-        $("#id_" + this.value).closest(".control-group").show();
+        $("#id_" + this.value).closest(".form-group").show();
       }
     });
   }
@@ -202,20 +285,19 @@ horizon.addInitFunction(function () {
 
   // Apply standard handler for everything but checkboxes.
   $(document).tooltip({
-    selector: "div.form-field :input:not(:checkbox)",
+    selector: "div.form-group .help-icon",
     placement: function (tip, input) {
       // Position to the right unless this is a "split" for in which case put
       // the tooltip below so it doesn't block the next field.
       return $(input).closest("form[class*='split']").length ? "bottom" : 'right';
     },
-    trigger: 'focus',
     title: function () {
-      return $(this).closest('div.form-field').children('.help-block').text();
+      return $(this).closest('div.form-group').children('.help-block').text();
     }
   });
   // Hide the tooltip upon interaction with the field for select boxes.
   // We use mousedown and keydown since those "open" the select dropdown.
-  $(document).on('mousedown keydown', '.form-field select', function (evt) {
+  $(document).on('mousedown keydown', '.form-group select', function (evt) {
     $(this).tooltip('hide');
   });
   // Hide the tooltip after escape button pressed
@@ -226,5 +308,5 @@ horizon.addInitFunction(function () {
   });
 
   // Hide the help text for js-capable browsers
-  $('span.help-block').hide();
+  $('p.help-block').hide();
 });
