@@ -1,5 +1,3 @@
-# vim: tabstop=4 shiftwidth=4 softtabstop=4
-#
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
 # a copy of the License at
@@ -17,14 +15,16 @@ from datetime import timedelta  # noqa
 
 import json
 
+from django.core.urlresolvers import reverse
 from django.http import HttpResponse   # noqa
 from django.utils.datastructures import SortedDict
 from django.utils.translation import ugettext_lazy as _
-from django.views.generic import TemplateView  # noqa
+import django.views
 
 from horizon import exceptions
 from horizon import tables
 from horizon import tabs
+from horizon.utils import csvbase
 
 from openstack_dashboard import api
 from openstack_dashboard.api import ceilometer
@@ -40,7 +40,7 @@ class IndexView(tabs.TabbedTableView):
     template_name = 'admin/metering/index.html'
 
 
-class SamplesView(TemplateView):
+class SamplesView(django.views.generic.TemplateView):
     template_name = "admin/metering/samples.csv"
 
     @staticmethod
@@ -52,11 +52,11 @@ class SamplesView(TemplateView):
         """Construct datapoint series for a meter from resource aggregates."""
         series = []
         for resource in aggregates:
-            if getattr(resource, meter_name):
+            if resource.get_meter(meter_name):
                 point = {'unit': unit,
                          'name': getattr(resource, resource_name),
                          'data': []}
-                for statistic in getattr(resource, meter_name):
+                for statistic in resource.get_meter(meter_name):
                     date = statistic.duration_end[:19]
                     value = float(getattr(statistic, stats_name))
                     point['data'].append({'x': date, 'y': value})
@@ -103,7 +103,7 @@ class ReportView(tables.MultiTableView):
     def get_tables(self):
         if self._tables:
             return self._tables
-        project_data = self.load_data(self.request)
+        project_data = load_report_data(self.request)
         table_instances = []
         limit = int(self.request.POST.get('limit', '1000'))
         for project in project_data.keys():
@@ -124,56 +124,42 @@ class ReportView(tables.MultiTableView):
         handled = self._tables[name].maybe_handle()
         return handled
 
-    def load_data(self, request):
-        meters = ceilometer.Meters(request)
-        services = {
-            _('Nova'): meters.list_nova(),
-            _('Neutron'): meters.list_neutron(),
-            _('Glance'): meters.list_glance(),
-            _('Cinder'): meters.list_cinder(),
-            _('Swift_meters'): meters.list_swift(),
-            _('Kwapi'): meters.list_kwapi(),
-        }
-        project_rows = {}
-        date_options = request.POST.get('date_options', None)
-        date_from = request.POST.get('date_from', None)
-        date_to = request.POST.get('date_to', None)
-        for meter in meters._cached_meters.values():
-            for name, m_list in services.items():
-                if meter in m_list:
-                    service = name
-            # show detailed samples
-            # samples = ceilometer.sample_list(request, meter.name)
-            res, unit = query_data(request,
-                                   date_from,
-                                   date_to,
-                                   date_options,
-                                   "project",
-                                   meter.name,
-                                   3600 * 24)
-            for re in res:
-                values = getattr(re, meter.name.replace(".", "_"))
-                if values:
-                    for value in values:
-                        row = {"name": 'none',
-                               "project": re.id,
-                               "meter": meter.name,
-                               "description": meter.description,
-                               "service": service,
-                               "time": value._apiresource.period_end,
-                               "value": value._apiresource.avg}
-                        if re.id not in project_rows:
-                            project_rows[re.id] = [row]
-                        else:
-                            project_rows[re.id].append(row)
-        return project_rows
-
     def get_context_data(self, **kwargs):
-        context = {}
-        context['tables'] = self.get_tables().values()
+        context = {'tables': self.get_tables().values()}
+        context['csv_url'] = reverse('horizon:admin:metering:csvreport')
         return context
 
 
+class CsvReportView(django.views.generic.View):
+    def get(self, request, **response_kwargs):
+        render_class = ReportCsvRenderer
+        response_kwargs.setdefault("filename", "usage.csv")
+        context = {'usage': load_report_data(request)}
+        resp = render_class(request=request,
+                            template=None,
+                            context=context,
+                            content_type='csv',
+                            **response_kwargs)
+        return resp
+
+
+class ReportCsvRenderer(csvbase.BaseCsvResponse):
+
+    columns = [_("Project Name"), _("Meter"), _("Description"),
+               _("Service"), _("Time"), _("Value (Avg)")]
+
+    def get_row_data(self):
+
+        for p in self.context['usage'].values():
+            for u in p:
+                yield (u["project"],
+                       u["meter"],
+                       u["description"],
+                       u["service"],
+                       u["time"],
+                       u["value"])
+
+
 def _calc_period(date_from, date_to):
     if date_from and date_to:
         if date_to < date_from:
@@ -222,8 +208,8 @@ def _calc_date_args(date_from, date_to, date_options):
             else:
                 date_to = datetime.now()
         except Exception:
-            raise ValueError("The dates haven't been "
-                             "recognized")
+            raise ValueError("The dates are not "
+                             "recognized.")
     else:
         try:
             date_from = datetime.now() - timedelta(days=int(date_options))
@@ -240,13 +226,15 @@ def query_data(request,
                date_options,
                group_by,
                meter,
-               period=None):
+               period=None,
+               additional_query=None):
     date_from, date_to = _calc_date_args(date_from,
                                          date_to,
                                          date_options)
     if not period:
         period = _calc_period(date_from, date_to)
-    additional_query = []
+    if additional_query is None:
+        additional_query = []
     if date_from:
         additional_query += [{'field': 'timestamp',
                               'op': 'ge',
@@ -273,7 +261,7 @@ def query_data(request,
         except Exception:
             tenants = []
             exceptions.handle(request,
-                              _('Unable to retrieve tenant list.'))
+                              _('Unable to retrieve project list.'))
         queries = {}
         for tenant in tenants:
             tenant_query = [{
@@ -314,3 +302,50 @@ def query_data(request,
             exceptions.handle(request,
                               _('Unable to retrieve statistics.'))
     return resources, unit
+
+
+def load_report_data(request):
+    meters = ceilometer.Meters(request)
+    services = {
+        _('Nova'): meters.list_nova(),
+        _('Neutron'): meters.list_neutron(),
+        _('Glance'): meters.list_glance(),
+        _('Cinder'): meters.list_cinder(),
+        _('Swift_meters'): meters.list_swift(),
+        _('Kwapi'): meters.list_kwapi(),
+    }
+    project_rows = {}
+    date_options = request.GET.get('date_options', 7)
+    date_from = request.GET.get('date_from')
+    date_to = request.GET.get('date_to')
+    for meter in meters._cached_meters.values():
+        service = None
+        for name, m_list in services.items():
+            if meter in m_list:
+                service = name
+                break
+        # show detailed samples
+        # samples = ceilometer.sample_list(request, meter.name)
+        res, unit = query_data(request,
+                               date_from,
+                               date_to,
+                               date_options,
+                               "project",
+                               meter.name,
+                               3600 * 24)
+        for re in res:
+            values = re.get_meter(meter.name.replace(".", "_"))
+            if values:
+                for value in values:
+                    row = {"name": 'none',
+                           "project": re.id,
+                           "meter": meter.name,
+                           "description": meter.description,
+                           "service": service,
+                           "time": value._apiresource.period_end,
+                           "value": value._apiresource.avg}
+                    if re.id not in project_rows:
+                        project_rows[re.id] = [row]
+                    else:
+                        project_rows[re.id].append(row)
+    return project_rows
