@@ -258,25 +258,10 @@ class DetailView(tabs.TabView):
 
     @memoized.memoized_method
     def get_data(self):
+        instance_id = self.kwargs['instance_id']
+
         try:
-            instance_id = self.kwargs['instance_id']
             instance = api.nova.server_get(self.request, instance_id)
-            status_label = [label for (value, label) in
-                            project_tables.STATUS_DISPLAY_CHOICES
-                            if value.lower() ==
-                            (instance.status or '').lower()]
-            if status_label:
-                instance.status_label = status_label[0]
-            else:
-                instance.status_label = instance.status
-            instance.volumes = api.nova.instance_volumes_list(self.request,
-                                                              instance_id)
-            # Sort by device name
-            instance.volumes.sort(key=lambda vol: vol.device)
-            instance.full_flavor = api.nova.flavor_get(
-                self.request, instance.flavor["id"])
-            instance.security_groups = api.network.server_security_groups(
-                self.request, instance_id)
         except Exception:
             redirect = reverse(self.redirect_url)
             exceptions.handle(self.request,
@@ -286,6 +271,41 @@ class DetailView(tabs.TabView):
             # Not all exception types handled above will result in a redirect.
             # Need to raise here just in case.
             raise exceptions.Http302(redirect)
+
+        status_label = [label for (value, label) in
+                        project_tables.STATUS_DISPLAY_CHOICES
+                        if value.lower() == (instance.status or '').lower()]
+        if status_label:
+            instance.status_label = status_label[0]
+        else:
+            instance.status_label = instance.status
+
+        try:
+            instance.volumes = api.nova.instance_volumes_list(self.request,
+                                                              instance_id)
+            # Sort by device name
+            instance.volumes.sort(key=lambda vol: vol.device)
+        except Exception:
+            msg = _('Unable to retrieve volume list for instance '
+                    '"%s".') % instance_id
+            exceptions.handle(self.request, msg, ignore=True)
+
+        try:
+            instance.full_flavor = api.nova.flavor_get(
+                self.request, instance.flavor["id"])
+        except Exception:
+            msg = _('Unable to retrieve flavor information for instance '
+                    '"%s".') % instance_id,
+            exceptions.handle(self.request, msg, ignore=True)
+
+        try:
+            instance.security_groups = api.network.server_security_groups(
+                self.request, instance_id)
+        except Exception:
+            msg = _('Unable to retrieve security groups for instance '
+                    '"%s".') % instance_id
+            exceptions.handle(self.request, msg, ignore=True)
+
         try:
             api.network.servers_update_addresses(self.request, [instance])
         except Exception:
@@ -293,6 +313,7 @@ class DetailView(tabs.TabView):
                 self.request,
                 _('Unable to retrieve IP addresses from Neutron for instance '
                   '"%s".') % instance_id, ignore=True)
+
         return instance
 
     def get_tabs(self, request, *args, **kwargs):
@@ -314,17 +335,23 @@ class ResizeView(workflows.WorkflowView):
         instance_id = self.kwargs['instance_id']
         try:
             instance = api.nova.server_get(self.request, instance_id)
-            flavor_id = instance.flavor['id']
-            flavors = self.get_flavors()
-            if flavor_id in flavors:
-                instance.flavor_name = flavors[flavor_id].name
-            else:
-                flavor = api.nova.flavor_get(self.request, flavor_id)
-                instance.flavor_name = flavor.name
         except Exception:
             redirect = reverse("horizon:project:instances:index")
             msg = _('Unable to retrieve instance details.')
             exceptions.handle(self.request, msg, redirect=redirect)
+        flavor_id = instance.flavor['id']
+        flavors = self.get_flavors()
+        if flavor_id in flavors:
+            instance.flavor_name = flavors[flavor_id].name
+        else:
+            try:
+                flavor = api.nova.flavor_get(self.request, flavor_id)
+                instance.flavor_name = flavor.name
+            except Exception:
+                msg = _('Unable to retrieve flavor information for instance '
+                        '"%s".') % instance_id
+                exceptions.handle(self.request, msg, ignore=True)
+                instance.flavor_name = _("Not available")
         return instance
 
     @memoized.memoized_method
